@@ -1,6 +1,6 @@
 use std::{thread, time::Duration};
 
-use log::LevelFilter;
+use log::{error, info, LevelFilter};
 use log4rs::{
     append::console::ConsoleAppender,
     config::{Appender, Config, Root},
@@ -8,8 +8,6 @@ use log4rs::{
 };
 use sentry_log4rs::SentryAppender;
 
-use log::{error, info};
-
 fn main() {
     let stdout = ConsoleAppender::builder().build();
     let sentry = SentryAppender::builder()
@@ -20,11 +18,11 @@ fn main() {
 
     let config = Config::builder()
         .appender(Appender::builder().build("stdout", Box::new(stdout)))
-        .appender(Appender::builder().build("sentry", Box::new(sentry)))
+        .appender(Appender::builder().build("my_sentry", Box::new(sentry)))
         .build(
             Root::builder()
                 .appender("stdout")
-                .appender("sentry")
+                .appender("my_sentry")
                 .build(LevelFilter::Info),
         )
         .unwrap();
